@@ -332,21 +332,21 @@ sub xexec_safe {
 sub xspawn {
     croak "xspawn: too few arguments" unless @_;
     local $^F = 0;
-    pipe READ, WRITE or die "pipe: $!";
+    pipe my $read, my $write or die "pipe: $!";
     if (my $pid = xfork) {
-        close WRITE;
-        local $_;    #local $/; not really necessary
-        while (<READ>) {
-            close READ;
+        close $write or die $!;
+        local $_;
+        while (<$read>) {    ## no critic, $_ is localized
+            close $read;
             croak "xspawn: can't exec \"$_[0]\": $_";
         }
-        close READ;
+        close $read or die $!;
         return $pid;
     } else {
         no warnings;
-        close READ;
+        close $read or die $!;
         exec @_;
-        select WRITE;
+        select $write or die $!;
         $| = 1;
         print $!;
         exit;
@@ -424,7 +424,7 @@ sub xwait {
     @_ == 0 or fp_croak_arity 0;
     my $kid = wait;
     defined $kid or die "xwait: $!";    # when can this happen? EINTR?
-    wantarray ? ($kid, $?) : $kid
+    wantarray ? ($kid, $?) : $kid       ## no critic
 }
 
 sub xxwait {
@@ -604,27 +604,34 @@ sub lstat_possiblyhires {
     }
 }
 
+# XX: should provide a newly named function to give the object,
+# instead of using wantarray. Have xstat behave like the Perl builtin
+# (and then possibly drop and replace by another solution from
+# core/CPAN).
 sub xstat {
     my @r;
     @_ <= 1 or croak "xstat: too many arguments";
     @r = stat_possiblyhires(@_ ? @_ : $_);
     @r or croak(@_ ? "xstat: '@_': $!" : "xstat: '$_': $!");
-    if (wantarray) {
+    my $wantarray = wantarray;    ## no critic
+    if ($wantarray) {
         @r
-    } elsif (defined wantarray) {
+    } elsif (defined $wantarray) {
         my $self = \@r;
         bless $self, 'Chj::xperlfunc::xstat'
     }
 }
 
+# XX ditto
 sub xlstat {
     my @r;
     @_ <= 1 or croak "xlstat: too many arguments";
     @r = lstat_possiblyhires(@_ ? @_ : $_);
     @r or croak(@_ ? "xlstat: '@_': $!" : "xlstat: '$_': $!");
-    if (wantarray) {
+    my $wantarray = wantarray;    ## no critic
+    if ($wantarray) {
         @r
-    } elsif (defined wantarray) {
+    } elsif (defined $wantarray) {
         my $self = \@r;
         bless $self, 'Chj::xperlfunc::xstat'
     }
@@ -632,6 +639,7 @@ sub xlstat {
 
 use Carp 'cluck';
 
+# XX ditto
 sub Xstat {
     my @r;
     @_ <= 1 or croak "Xstat: too many arguments";
@@ -643,16 +651,18 @@ sub Xstat {
             croak(@_ ? "Xstat: '@_': $!" : "Xstat: '$_': $!");
         }
     };
-    if (wantarray) {
+    my $wantarray = wantarray;    ## no critic
+    if ($wantarray) {
         cluck "Xstat call in array context doesn't make sense";
         @r
-    } elsif (defined wantarray) {
+    } elsif (defined $wantarray) {
         bless \@r, 'Chj::xperlfunc::xstat'
     } else {
         cluck "Xstat call in void context doesn't make sense";
     }
 }
 
+# XX ditto
 sub Xlstat {
     @_ <= 2 or croak "Xlstat: too many arguments";
     my ($path, $accept_errors) = @_;
@@ -665,10 +675,11 @@ sub Xlstat {
             croak("Xlstat: '$path': $!");
         }
     };
-    if (wantarray) {
+    my $wantarray = wantarray;    ## no critic
+    if ($wantarray) {
         cluck "Xlstat call in array context doesn't make sense";
         @r
-    } elsif (defined wantarray) {
+    } elsif (defined $wantarray) {
         bless \@r, 'Chj::xperlfunc::xstat'
     } else {
         cluck "Xlstat call in void context doesn't make sense";
@@ -689,7 +700,7 @@ sub mk_caching_getANYid {
                 $v = [&$function($id)];
                 $cache{$id} = $v;
             }
-            wantarray ? @$v : $$v[$scalarindex]
+            wantarray ? @$v : $$v[$scalarindex]    ## no critic
         } else {
             croak "$methodname: got undefined value";
         }
@@ -712,7 +723,8 @@ sub fstype_for_device_init {
     open my $mounts, "<", "/proc/mounts" or die "/proc/mounts: $!";
     local $/ = "\n";
     my %t;
-    while (<$mounts>) {
+    local $_;
+    while (<$mounts>) {    ## no critic, $_ is localized
         my @f = split / /, $_;
         my ($_dev, $mountpoint, $fstype) = @f;
         if (
@@ -1125,7 +1137,7 @@ sub XLmtime {
 
     sub unixtime {
         my $s = shift;
-        &Time::Local::timelocal(@$s)
+        Time::Local::timelocal(@$s)
     }
 }
 
@@ -1242,8 +1254,9 @@ sub xchroot {
 sub xeval {    # meant for string eval only, of course.
     @_ == 1 or die "wrong number of arguments";
     ## hm ps should one localize $@ here?
-    if (defined wantarray) {
-        if (wantarray) {
+    my $wantarray = wantarray;    ## no critic
+    if (defined $wantarray) {
+        if ($wantarray) {
             my @res = eval $_[0];
             if (ref $@ or $@) {
                 die $@
@@ -1424,7 +1437,7 @@ sub xlink_p {
         my ($user) = @_;
         my $s      = bless [getpwnam($user)], $class;
         if (@$s) {
-            wantarray ? @$s : $s
+            wantarray ? @$s : $s    ## no critic
         } else {
             return
         }
@@ -1435,7 +1448,7 @@ sub xlink_p {
 sub xgetpwnam {
     @_ == 1 or fp_croak_arity 1;
     my ($user) = @_;
-    if (wantarray) {
+    if (wantarray) {                ## no critic
         my @f = Chj::xperlfunc::Getpwnam->perhaps_get($user);
         @f or croak "xgetpwnam: '$user' not in passwd file";
         @f
@@ -1455,7 +1468,7 @@ sub xgetpwnam {
         my ($user) = @_;
         my $s      = bless [getgrnam($user)], $class;
         if (@$s) {
-            wantarray ? @$s : $s
+            wantarray ? @$s : $s    ## no critic
         } else {
             return
         }
@@ -1466,7 +1479,7 @@ sub xgetpwnam {
 sub xgetgrnam {
     @_ == 1 or fp_croak_arity 1;
     my ($group) = @_;
-    if (wantarray) {
+    if (wantarray) {                ## no critic
         my @f = Chj::xperlfunc::Getgrnam->perhaps_get($group);
         @f or croak "xgetgrnam: '$group' not in group file";
         @f
