@@ -119,7 +119,7 @@ use Chj::xoutpipe();
 use Chj::xtmpfile;
 use Chj::xperlfunc qw(xexec xstat);
 use Chj::xopen qw(fh_to_fh perhaps_xopen_read);
-use POSIX;
+use POSIX qw(sigaction SIGINT);
 use Chj::xhome qw(xsafehome);
 use Chj::singlequote 'singlequote';
 use FP::HashSet qw(hashset_union);
@@ -587,11 +587,11 @@ sub eval_code {
         if (defined $maybe_lexicals) {
             $lp->lexicals(hashset_union($lp->lexicals, $maybe_lexicals))
         }
-        my $context = wantarray ? "list" : "scalar";
+        my $context = wantarray ? "list" : "scalar";    ## no critic
         $lp->context($context);
         WithRepl_eval { $lp->eval($allcode) }
     } else {
-        my @v = sort keys %$maybe_lexicals if defined $maybe_lexicals;
+        my @v = sort keys %{ $maybe_lexicals // {} };
         my $allcode
             = $prelude
             . (@v ? 'my (' . join(", ", @v) . '); ' : '') . 'sub {'
@@ -904,7 +904,8 @@ sub run {
 
         # It seems this is the only way to make signal handlers work in
         # both perl 5.6 and 5.8:
-        sigaction SIGINT, new POSIX::SigAction __PACKAGE__ . '::__signalhandler'
+        sigaction SIGINT,
+            POSIX::SigAction->new(__PACKAGE__ . '::__signalhandler')
             or die "Error setting SIGINT handler: $!\n";
         1
     } || do {
@@ -924,7 +925,7 @@ sub run {
 
     # only start one readline instance, do not nest (doing otherwise
     # seems to lead to segfaults). okay?.
-    local our $term = $term || new Term::ReadLine 'Repl';
+    local our $term = $term || Term::ReadLine->new('Repl');
 
     # This means that the history from nested repls will also show up
     # in the history of the parent repl. Not saved, but within the
